@@ -19,37 +19,63 @@ import pandas as pd
 import yaml
 
 from ludwig.api import LudwigModel
-from ludwig.automl.auto_tune_config import memory_tune_config
-from ludwig.automl.base_config import _create_default_config, _get_reference_configs, DatasetInfo, get_dataset_info
+from ludwig.api_annotations import DeveloperAPI, PublicAPI
+from ludwig.automl.base_config import (
+    allocate_experiment_resources,
+    create_default_config,
+    DatasetInfo,
+    get_dataset_info,
+    get_default_automl_hyperopt,
+    get_features_config,
+    get_reference_configs,
+    get_resource_aware_hyperopt_config,
+)
 from ludwig.backend import Backend, initialize_backend
 from ludwig.constants import (
+    AUTO,
     AUTOML_DEFAULT_IMAGE_ENCODER,
     AUTOML_DEFAULT_TABULAR_MODEL,
     AUTOML_DEFAULT_TEXT_ENCODER,
+    BINARY,
+    CATEGORY,
+    ENCODER,
     HYPEROPT,
     IMAGE,
+    INPUT_FEATURES,
+    NAME,
+    NUMBER,
+    OUTPUT_FEATURES,
     TABULAR,
     TEXT,
+    TRAINER,
+    TYPE,
 )
 from ludwig.contrib import add_contrib_callback_args
+from ludwig.data.cache.types import CacheableDataset
+from ludwig.datasets import load_dataset_uris
 from ludwig.globals import LUDWIG_VERSION
 from ludwig.hyperopt.run import hyperopt
-from ludwig.utils.automl.ray_utils import _ray_init
-from ludwig.utils.automl.utils import (
-    _add_transfer_config,
-    get_model_type,
-    has_imbalanced_output,
-    set_output_feature_metric,
+from ludwig.profiling import dataset_profile_pb2
+from ludwig.profiling.dataset_profile import (
+    get_column_profile_summaries_from_proto,
+    get_dataset_profile_proto,
+    get_dataset_profile_view,
 )
+from ludwig.profiling.type_inference import get_ludwig_type_map_from_column_profile_summaries
+from ludwig.schema.model_config import ModelConfig
+from ludwig.types import ModelConfigDict
+from ludwig.utils.automl.ray_utils import _ray_init
+from ludwig.utils.automl.utils import _add_transfer_config, get_model_type, set_output_feature_metric
 from ludwig.utils.data_utils import load_dataset, use_credentials
 from ludwig.utils.defaults import default_random_seed
 from ludwig.utils.fs_utils import open_file
+from ludwig.utils.heuristics import get_auto_learning_rate
 from ludwig.utils.misc_utils import merge_dict
 from ludwig.utils.print_utils import print_ludwig
+from ludwig.utils.types import DataFrame
 
 try:
     import dask.dataframe as dd
-    import ray
     from ray.tune import ExperimentAnalysis
 except ImportError as e:
     raise RuntimeError("ray is not installed. In order to use auto_train please run pip install ludwig[ray]") from e
@@ -58,6 +84,7 @@ except ImportError as e:
 logger = logging.getLogger(__name__)
 
 OUTPUT_DIR = "."
+TABULAR_TYPES = {CATEGORY, NUMBER, BINARY}
 
 
 class AutoTrainResults:
@@ -91,6 +118,7 @@ class AutoTrainResults:
                 return LudwigModel.load(os.path.join(ckpt_path, "model"))
 
 
+@PublicAPI
 def auto_train(
     dataset: Union[str, pd.DataFrame, dd.core.DataFrame],
     target: str,
@@ -129,21 +157,91 @@ def auto_train(
     :return: (AutoTrainResults) results containing hyperopt experiments and best model
     """
     config = create_auto_config(
-        dataset, target, time_limit_s, tune_for_memory, user_config, random_seed, use_reference_config
+        dataset,
+        target,
+        time_limit_s,
+        tune_for_memory,
+        user_config,
+        random_seed,
+        use_reference_config=use_reference_config,
     )
     return train_with_config(dataset, config, output_directory=output_directory, random_seed=random_seed, **kwargs)
 
 
+@DeveloperAPI
+def create_auto_config_with_dataset_profile(
+    target: str,
+    dataset: Optional[Union[str, DataFrame]] = None,
+    dataset_profile: dataset_profile_pb2.DatasetProfile = None,
+    random_seed: int = default_random_seed,
+    include_hyperopt: bool = False,
+    time_limit_s: Union[int, float] = None,
+    backend: Union[Backend, str] = None,
+) -> dict:
+    """Returns the best single-shot Ludwig config given a Ludwig dataset or dataset profile.
+
+    If only the dataset is provided, then a new profile is computed.
+    Only one of the dataset or dataset_profile should be specified, not both.
+
+    This function is intended to eventually replace create_auto_config().
+    """
+    if dataset is None and dataset_profile is None:
+        raise ValueError("Please specify either a dataset or a dataset_profile.")
+    if dataset is not None and dataset_profile is not None:
+        raise ValueError("Please specify either a dataset or a dataset_profile. It is an error to specify both.")
+
+    # Get the dataset profile.
+    if dataset_profile is None:
+        dataset_profile = get_dataset_profile_proto(get_dataset_profile_view(dataset))
+
+    # Use the dataset profile to get Ludwig types.
+    ludwig_type_map = get_ludwig_type_map_from_column_profile_summaries(
+        get_column_profile_summaries_from_proto(dataset_profile)
+    )
+
+    # Add features along with their profiled types.
+    automl_config = {}
+    automl_config[INPUT_FEATURES] = []
+    automl_config[OUTPUT_FEATURES] = []
+    for feature_name, ludwig_type in ludwig_type_map.items():
+        if feature_name == target:
+            automl_config[OUTPUT_FEATURES].append({"name": feature_name, "type": ludwig_type})
+        else:
+            automl_config[INPUT_FEATURES].append({"name": feature_name, "type": ludwig_type})
+
+    # Set the combiner to tabnet, by default.
+    # TODO(travis): consolidate this logic with `create_auto_config` to reduce duplication and make the
+    # switch easier
+    automl_config.get("combiner", {})[TYPE] = "tabnet"
+
+    # Add hyperopt, if desired.
+    if include_hyperopt:
+        automl_config[HYPEROPT] = get_default_automl_hyperopt()
+
+        # Merge resource-sensitive settings.
+        backend = initialize_backend(backend)
+        resources = backend.get_available_resources()
+        experiment_resources = allocate_experiment_resources(resources)
+        automl_config = merge_dict(
+            automl_config, get_resource_aware_hyperopt_config(experiment_resources, time_limit_s, random_seed)
+        )
+
+    # TODO: Adjust preprocessing parameters according to output feature imbalance.
+    return automl_config
+
+
+@PublicAPI
 def create_auto_config(
     dataset: Union[str, pd.DataFrame, dd.core.DataFrame, DatasetInfo],
     target: Union[str, List[str]],
     time_limit_s: Union[int, float],
-    tune_for_memory: bool,
+    tune_for_memory: bool = False,
     user_config: Dict = None,
     random_seed: int = default_random_seed,
+    imbalance_threshold: float = 0.9,
     use_reference_config: bool = False,
     backend: Union[Backend, str] = None,
-) -> dict:
+) -> ModelConfigDict:
     """Returns an auto-generated Ludwig config with the intent of training the best model on given given dataset /
     target in the given time limit.
 
@@ -152,13 +250,14 @@ def create_auto_config(
     :param target: (str, List[str]) name of target feature
     :param time_limit_s: (int, float) total time allocated to auto_train. acts
                          as the stopping parameter
-    :param tune_for_memory: (bool) refine hyperopt search space for available
+    :param tune_for_memory: (bool) DEPRECATED refine hyperopt search space for available
                             host / GPU memory
     :param user_config: (dict) override automatic selection of specified config items
     :param random_seed: (int, default: `42`) a random seed that will be used anywhere
                         there is a call to a random number generator, including
                         hyperparameter search sampling, as well as data splitting,
                         parameter initialization and training set shuffling
+    :param imbalance_threshold: (float) maximum imbalance ratio (minority / majority) to perform stratified sampling
     :param use_reference_config: (bool) refine hyperopt search space by setting first
                                  search point from reference model config, if any
 
@@ -168,35 +267,60 @@ def create_auto_config(
     backend = initialize_backend(backend)
 
     if not isinstance(dataset, DatasetInfo):
+        # preload ludwig datasets
+        dataset, _, _, _ = load_dataset_uris(dataset, None, None, None, backend)
+        if isinstance(dataset, CacheableDataset):
+            dataset = dataset.unwrap()
         dataset = load_dataset(dataset, df_lib=backend.df_engine.df_lib)
 
     dataset_info = get_dataset_info(dataset) if not isinstance(dataset, DatasetInfo) else dataset
-    default_configs, features_metadata = _create_default_config(
-        dataset_info, target, time_limit_s, random_seed, backend
+    features_config = create_features_config(dataset_info, target)
+    return create_automl_config_for_features(
+        features_config,
+        dataset_info,
+        target,
+        time_limit_s=time_limit_s,
+        user_config=user_config,
+        random_seed=random_seed,
+        imbalance_threshold=imbalance_threshold,
+        use_reference_config=use_reference_config,
+        backend=backend,
     )
-    model_config, model_category, row_count = _model_select(
-        dataset_info, default_configs, features_metadata, user_config, use_reference_config
+
+
+@PublicAPI
+def create_automl_config_for_features(
+    features_config: ModelConfigDict,
+    dataset_info: DatasetInfo,
+    target: Union[str, List[str]],
+    time_limit_s: Union[int, float],
+    tune_for_memory: bool = False,
+    user_config: Dict = None,
+    random_seed: int = default_random_seed,
+    imbalance_threshold: float = 0.9,
+    use_reference_config: bool = False,
+    backend: Union[Backend, str] = None,
+) -> ModelConfigDict:
+    default_configs = create_default_config(
+        features_config, dataset_info, target, time_limit_s, random_seed, imbalance_threshold, backend
     )
+    model_config, _, _ = _model_select(dataset_info, default_configs, user_config, use_reference_config)
+
     if tune_for_memory:
-        args = (model_config, dataset, model_category, row_count, backend)
-        if ray.is_initialized():
-            resources = backend.get_available_resources()  # check if cluster has GPUS
-            if resources.gpus > 0:
-                model_config, fits_in_memory = ray.get(
-                    ray.remote(num_gpus=1, num_cpus=1, max_calls=1)(memory_tune_config).remote(*args)
-                )
-            else:
-                model_config, fits_in_memory = ray.get(ray.remote(num_cpus=1)(memory_tune_config).remote(*args))
-        else:
-            model_config, fits_in_memory = memory_tune_config(*args)
-        if not fits_in_memory:
-            warnings.warn(
-                "AutoML with tune_for_memory enabled did not return estimation that model will fit in memory. "
-                "If out-of-memory occurs, consider setting AutoML user_config to reduce model memory footprint. "
-            )
+        warnings.warn("`tune_for_memory=True` is deprecated, `batch_size=auto` will be used instead")
+
     return model_config
 
 
+@PublicAPI
+def create_features_config(
+    dataset_info: DatasetInfo,
+    target_name: Union[str, List[str]] = None,
+) -> ModelConfigDict:
+    return get_features_config(dataset_info.fields, dataset_info.row_count, target_name)
+
+
+@PublicAPI
 def train_with_config(
     dataset: Union[str, pd.DataFrame, dd.core.DataFrame],
     config: dict,
@@ -251,7 +375,6 @@ def train_with_config(
 def _model_select(
     dataset_info: DatasetInfo,
     default_configs,
-    features_metadata,
     user_config,
     use_reference_config: bool,
 ):
@@ -261,11 +384,13 @@ def _model_select(
     """
     fields = dataset_info.fields
 
-    base_config = default_configs["base_config"]
+    base_config = copy.deepcopy(default_configs["base_config"])
     model_category = None
 
+    input_features = default_configs["base_config"]["input_features"]
+
     # tabular dataset heuristics
-    if len(fields) > 3:
+    if len(fields) > 3 and all(f[TYPE] in TABULAR_TYPES for f in input_features):
         model_category = TABULAR
         base_config = merge_dict(base_config, default_configs["combiner"][AUTOML_DEFAULT_TABULAR_MODEL])
 
@@ -276,19 +401,40 @@ def _model_select(
                 base_config = merge_dict(base_config, default_configs["combiner"][model_type])
     else:
         # text heuristics
-        for input_feature in base_config["input_features"]:
+        for i, input_feature in enumerate(input_features):
+            base_config_input_feature = base_config["input_features"][i]
             # default text encoder is bert
-            if input_feature["type"] == TEXT:
+            if input_feature[TYPE] == TEXT:
                 model_category = TEXT
-                input_feature["encoder"] = AUTOML_DEFAULT_TEXT_ENCODER
-                base_config = merge_dict(base_config, default_configs[TEXT][AUTOML_DEFAULT_TEXT_ENCODER])
+                if ENCODER in input_feature:
+                    base_config_input_feature[ENCODER][TYPE] = AUTOML_DEFAULT_TEXT_ENCODER
+                else:
+                    base_config_input_feature[ENCODER] = {TYPE: AUTOML_DEFAULT_TEXT_ENCODER}
+                # TODO(shreya): Should this hyperopt config param be set here?
                 base_config[HYPEROPT]["executor"]["num_samples"] = 5  # set for small hyperparameter search space
+                base_config = merge_dict(base_config, default_configs[TEXT][AUTOML_DEFAULT_TEXT_ENCODER])
 
             # TODO (ASN): add image heuristics
-            if input_feature["type"] == IMAGE:
+            if input_feature[TYPE] == IMAGE:
                 model_category = IMAGE
-                input_feature["encoder"] = AUTOML_DEFAULT_IMAGE_ENCODER
-                base_config = merge_dict(base_config, default_configs["combiner"]["concat"])
+                if ENCODER in input_feature:
+                    base_config_input_feature[ENCODER][TYPE] = AUTOML_DEFAULT_IMAGE_ENCODER
+                else:
+                    base_config_input_feature[ENCODER] = {TYPE: AUTOML_DEFAULT_IMAGE_ENCODER}
+
+        # Merge combiner config
+        base_config = merge_dict(base_config, default_configs["combiner"]["concat"])
+
+    # Adjust learning rate based on other config settings
+    if base_config[TRAINER]["learning_rate"] == AUTO:
+        # Add a fake output feature to ensure we can load the ModelConfig, as we expect there to be at least
+        # one output feature in all cases
+        # TODO(travis): less hacky way to do this, we should probably allow ModelConfig to be created without output
+        # features
+        load_config = copy.deepcopy(base_config)
+        if not load_config.get(OUTPUT_FEATURES):
+            load_config[OUTPUT_FEATURES] = [{"name": "fake", "type": "binary"}]
+        base_config[TRAINER]["learning_rate"] = get_auto_learning_rate(ModelConfig.from_dict(load_config))
 
     # override and constrain automl config based on user specified values
     if user_config is not None:
@@ -303,17 +449,13 @@ def _model_select(
                 if param in user_config[config_section]:
                     del base_config["hyperopt"]["parameters"][hyperopt_params]
 
-    # check if any binary or category output feature has highly imbalanced minority vs majority values
-    # note: check is done after any relevant user_config has been applied
-    has_imbalanced_output(base_config, features_metadata)
-
     # if single output feature, set relevant metric and goal if not already set
     base_config = set_output_feature_metric(base_config)
 
     # add as initial trial in the automl search the hyperparameter settings from
     # the best model for a similar dataset and matching model type, if any.
     if use_reference_config:
-        ref_configs = _get_reference_configs()
+        ref_configs = get_reference_configs()
         base_config = _add_transfer_config(base_config, ref_configs)
 
     return base_config, model_category, dataset_info.row_count
@@ -343,7 +485,8 @@ def init_config(
     dataset: str,
     target: Union[str, List[str]],
     time_limit_s: Union[int, float],
-    tune_for_memory: bool,
+    tune_for_memory: bool = False,
+    suggested: bool = False,
     hyperopt: bool = False,
     output: str = None,
     random_seed: int = default_random_seed,
@@ -354,14 +497,24 @@ def init_config(
         dataset=dataset,
         target=target,
         time_limit_s=time_limit_s,
-        tune_for_memory=tune_for_memory,
         random_seed=random_seed,
         use_reference_config=use_reference_config,
+        tune_for_memory=tune_for_memory,
     )
 
     if HYPEROPT in config and not hyperopt:
         del config[HYPEROPT]
 
+    if not suggested:
+        # Only use inputs and outputs
+        minimal_config = {
+            INPUT_FEATURES: [{"name": f[NAME], "type": f[TYPE]} for f in config[INPUT_FEATURES]],
+            OUTPUT_FEATURES: [{"name": f[NAME], "type": f[TYPE]} for f in config[OUTPUT_FEATURES]],
+        }
+        if hyperopt:
+            minimal_config[HYPEROPT] = config[HYPEROPT]
+        config = minimal_config
+
     if output is None:
         print(yaml.safe_dump(config, None, sort_keys=False))
     else:
@@ -396,9 +549,9 @@ def cli_init_config(sys_argv):
         required=False,
     )
     parser.add_argument(
-        "--tune_for_memory",
+        "--suggested",
         type=bool,
-        help="refine hyperopt search space based on available host / GPU memory",
+        help="use suggested config from automl, otherwise only use inferred types and return a minimal config",
         default=False,
         required=False,
     )
