@@ -65,7 +65,6 @@ from ludwig.schema.encoders.utils import get_encoder_cls
 from ludwig.types import FeatureConfigDict, PreprocessingConfigDict, TrainingSetMetadataDict
 from ludwig.utils import data_utils, strings_utils
 from ludwig.utils.backward_compatibility import upgrade_metadata
-from ludwig.utils.config_utils import merge_config_preprocessing_with_feature_specific_defaults
 from ludwig.utils.data_utils import (
     CACHEABLE_FORMATS,
     CSV_FORMATS,
@@ -108,7 +107,11 @@ from ludwig.utils.data_utils import (
     TSV_FORMATS,
 )
 from ludwig.utils.dataframe_utils import is_dask_series_or_df
-from ludwig.utils.defaults import default_preprocessing_parameters, default_random_seed
+from ludwig.utils.defaults import (
+    default_prediction_preprocessing_parameters,
+    default_random_seed,
+    default_training_preprocessing_parameters,
+)
 from ludwig.utils.fs_utils import file_lock, path_exists
 from ludwig.utils.misc_utils import get_from_registry, merge_dict
 from ludwig.utils.types import DataFrame, Series
@@ -130,7 +133,7 @@ class DataFormatPreprocessor(ABC):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -152,7 +155,7 @@ class DataFormatPreprocessor(ABC):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
     ):
@@ -170,7 +173,7 @@ class DictPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -208,10 +211,10 @@ class DictPreprocessor(DataFormatPreprocessor):
             pd.DataFrame(dataset),
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -227,7 +230,7 @@ class DataFramePreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -262,10 +265,10 @@ class DataFramePreprocessor(DataFormatPreprocessor):
             dataset,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -281,7 +284,7 @@ class CSVPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -310,10 +313,10 @@ class CSVPreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -329,7 +332,7 @@ class TSVPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -358,10 +361,10 @@ class TSVPreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -377,7 +380,7 @@ class JSONPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -406,10 +409,10 @@ class JSONPreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -425,7 +428,7 @@ class JSONLPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -454,10 +457,10 @@ class JSONLPreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -473,7 +476,7 @@ class ExcelPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -502,10 +505,10 @@ class ExcelPreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -521,7 +524,7 @@ class ParquetPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -550,10 +553,10 @@ class ParquetPreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -566,7 +569,7 @@ class ParquetPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
     ):
@@ -598,7 +601,7 @@ class PicklePreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -627,10 +630,10 @@ class PicklePreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -646,7 +649,7 @@ class FatherPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -675,10 +678,10 @@ class FatherPreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -694,7 +697,7 @@ class FWFPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -723,10 +726,10 @@ class FWFPreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -742,7 +745,7 @@ class HTMLPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -771,10 +774,10 @@ class HTMLPreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -790,7 +793,7 @@ class ORCPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -819,10 +822,10 @@ class ORCPreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -838,7 +841,7 @@ class SASPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -867,10 +870,10 @@ class SASPreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -886,7 +889,7 @@ class SPSSPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -915,10 +918,10 @@ class SPSSPreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -934,7 +937,7 @@ class StataPreprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -963,10 +966,10 @@ class StataPreprocessor(DataFormatPreprocessor):
             dataset_df,
             features,
             preprocessing_params,
+            mode="prediction",
             metadata=training_set_metadata,
             backend=backend,
             callbacks=callbacks,
-            mode="prediction",
         )
         return dataset, training_set_metadata, None
 
@@ -982,7 +985,7 @@ class HDF5Preprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
         callbacks=None,
@@ -1015,7 +1018,7 @@ class HDF5Preprocessor(DataFormatPreprocessor):
         test_set=None,
         training_set_metadata=None,
         skip_save_processed_input=False,
-        preprocessing_params=default_preprocessing_parameters,
+        preprocessing_params=default_training_preprocessing_parameters,
         backend=LOCAL_BACKEND,
         random_seed=default_random_seed,
     ):
@@ -1086,13 +1089,30 @@ def build_dataset(
     dataset_df,
     features,
     global_preprocessing_parameters,
+    mode,
     metadata=None,
     backend=LOCAL_BACKEND,
     random_seed=default_random_seed,
     skip_save_processed_input=False,
     callbacks=None,
-    mode=None,
 ):
+    """Builds a dataset from a dataframe and a list of features.
+
+    Args:
+        dataset_df: Pandas or Dask dataframe
+        features: List of features
+        global_preprocessing_parameters: Global preprocessing parameters
+        mode: One of ['training', 'prediction']
+        metadata: Training set metadata if available
+        backend: Backend
+        random_seed: Random seed
+        skip_save_processed_input: Whether to skip saving the processed input
+        callbacks: List of callbacks
+
+    Returns:
+        A tuple of (dataset, metadata)
+    """
+
     df_engine = backend.df_engine
 
     if df_engine.partitioned:
@@ -1117,15 +1137,28 @@ def build_dataset(
 
     dataset_df = df_engine.parallelize(dataset_df)
 
-    sample_ratio = global_preprocessing_parameters["sample_ratio"]
-    if sample_ratio < 1.0:
-        logger.debug(f"sample {sample_ratio} of data")
-        dataset_df = dataset_df.sample(frac=sample_ratio)
+    if mode == "training":
+        sample_ratio = global_preprocessing_parameters["sample_ratio"]
+        if sample_ratio < 1.0:
+            if not df_engine.partitioned and len(dataset_df) * sample_ratio < 1:
+                raise ValueError(
+                    f"sample_ratio {sample_ratio} is too small for dataset of length {len(dataset_df)}. "
+                    f"Please increase sample_ratio or use a larger dataset."
+                )
+
+            logger.debug(f"sample {sample_ratio} of data")
+            dataset_df = dataset_df.sample(frac=sample_ratio, random_state=random_seed)
 
     # If persisting DataFrames in memory is enabled, we want to do this after
     # each batch of parallel ops in order to avoid redundant computation
     dataset_df = df_engine.persist(dataset_df)
 
+    if mode == "training":
+        default_preprocessing_parameters = default_training_preprocessing_parameters
+    elif mode == "prediction":
+        default_preprocessing_parameters = default_prediction_preprocessing_parameters
+    else:
+        raise ValueError(f"Invalid mode {mode}")
     global_preprocessing_parameters = merge_dict(default_preprocessing_parameters, global_preprocessing_parameters)
 
     # Get all the unique preprocessing features to compute
@@ -1457,7 +1490,13 @@ def build_data(
     return proc_cols
 
 
-def balance_data(dataset_df: DataFrame, output_features: List[Dict], preprocessing_parameters: Dict, backend: Backend):
+def balance_data(
+    dataset_df: DataFrame,
+    output_features: List[Dict],
+    preprocessing_parameters: Dict,
+    backend: Backend,
+    random_seed: int,
+):
     """The purpose of this function is to balance the training dataset using either over-sampling or under-
     sampling.
 
@@ -1466,6 +1505,7 @@ def balance_data(dataset_df: DataFrame, output_features: List[Dict], preprocessi
         output_features: List of feature configs.
         preprocessing_parameters: Dictionary of the global preprocessing parameters.
         backend: Backend for data processing.
+        random_seed: Integer to seed the random sampling to ensure determinism.
 
     Returns: An over-sampled or under-sampled training dataset.
     """
@@ -1482,10 +1522,10 @@ def balance_data(dataset_df: DataFrame, output_features: List[Dict], preprocessi
 
     if preprocessing_parameters["oversample_minority"]:
         sample_fraction = (len(majority_df) * preprocessing_parameters["oversample_minority"]) / len(minority_df)
-        minority_df = minority_df.sample(frac=sample_fraction, replace=True)
+        minority_df = minority_df.sample(frac=sample_fraction, replace=True, random_state=random_seed)
     elif preprocessing_parameters["undersample_majority"]:
         sample_fraction = int(len(minority_df) / preprocessing_parameters["undersample_majority"]) / len(majority_df)
-        majority_df = majority_df.sample(frac=sample_fraction, replace=False)
+        majority_df = majority_df.sample(frac=sample_fraction, replace=False, random_state=random_seed)
 
     balanced_df = backend.df_engine.concat([minority_df, majority_df])
 
@@ -1652,7 +1692,7 @@ def preprocess_for_training(
     training_set_metadata=None,
     data_format=None,
     skip_save_processed_input=False,
-    preprocessing_params=default_preprocessing_parameters,
+    preprocessing_params=default_training_preprocessing_parameters,
     backend=LOCAL_BACKEND,
     random_seed=default_random_seed,
     callbacks=None,
@@ -1830,7 +1870,7 @@ def _preprocess_file_for_training(
     training_set_metadata=None,
     read_fn=read_csv,
     skip_save_processed_input=False,
-    preprocessing_params=default_preprocessing_parameters,
+    preprocessing_params=default_training_preprocessing_parameters,
     backend=LOCAL_BACKEND,
     random_seed=default_random_seed,
     callbacks=None,
@@ -1862,12 +1902,12 @@ def _preprocess_file_for_training(
             dataset_df,
             features,
             preprocessing_params,
+            mode="training",
             metadata=training_set_metadata,
             backend=backend,
             random_seed=random_seed,
             skip_save_processed_input=skip_save_processed_input,
             callbacks=callbacks,
-            mode="training",
         )
 
     elif training_set:
@@ -1887,11 +1927,11 @@ def _preprocess_file_for_training(
             concatenated_df,
             features,
             preprocessing_params,
+            mode="training",
             metadata=training_set_metadata,
             backend=backend,
             random_seed=random_seed,
             callbacks=callbacks,
-            mode="training",
         )
 
     else:
@@ -1914,7 +1954,9 @@ def _preprocess_file_for_training(
 
     logger.info("Building dataset: DONE")
     if preprocessing_params["oversample_minority"] or preprocessing_params["undersample_majority"]:
-        training_data = balance_data(training_data, config["output_features"], preprocessing_params, backend)
+        training_data = balance_data(
+            training_data, config["output_features"], preprocessing_params, backend, random_seed
+        )
 
     return training_data, test_data, validation_data, training_set_metadata
 
@@ -1927,7 +1969,7 @@ def _preprocess_df_for_training(
     validation_set=None,
     test_set=None,
     training_set_metadata=None,
-    preprocessing_params=default_preprocessing_parameters,
+    preprocessing_params=default_training_preprocessing_parameters,
     backend=LOCAL_BACKEND,
     random_seed=default_random_seed,
     callbacks=None,
@@ -1954,11 +1996,11 @@ def _preprocess_df_for_training(
         dataset,
         features,
         preprocessing_params,
+        mode="training",
         metadata=training_set_metadata,
         random_seed=random_seed,
         backend=backend,
         callbacks=callbacks,
-        mode="training",
     )
 
     logger.debug("split train-val-test")
@@ -1966,7 +2008,7 @@ def _preprocess_df_for_training(
 
     logger.info("Building dataset: DONE")
     if preprocessing_params["oversample_minority"] or preprocessing_params["undersample_majority"]:
-        training_set = balance_data(training_set, config["output_features"], preprocessing_params, backend)
+        training_set = balance_data(training_set, config["output_features"], preprocessing_params, backend, random_seed)
 
     return training_set, test_set, validation_set, training_set_metadata
 
@@ -2016,10 +2058,13 @@ def preprocess_for_prediction(
         if num_overrides > 0:
             logger.warning("Using in_memory = False is not supported " "with {} data format.".format(data_format))
 
-    preprocessing_params = merge_config_preprocessing_with_feature_specific_defaults(
-        config.get(PREPROCESSING, {}), config.get(DEFAULTS, {})
-    )
-    preprocessing_params = merge_dict(default_preprocessing_parameters, preprocessing_params)
+    preprocessing_params = {}
+    config_defaults = config.get(DEFAULTS, {})
+    for feature_type in config_defaults:
+        preprocessing_params[feature_type] = config_defaults[feature_type].get(PREPROCESSING, {})
+    preprocessing_params[SPLIT] = config.get(PREPROCESSING, {}).get(SPLIT, {})
+
+    preprocessing_params = merge_dict(default_prediction_preprocessing_parameters, preprocessing_params)
 
     # if training_set_metadata is a string, assume it's a path to load the json
     if training_set_metadata and isinstance(training_set_metadata, str):
