@@ -1,5 +1,4 @@
 #! /usr/bin/env python
-# coding=utf-8
 # Copyright (c) 2020 Uber Technologies, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -17,22 +16,22 @@
 
 from abc import ABC, abstractmethod
 
-from tensorflow.keras.layers import Layer
+from torch import nn
 
-from ludwig.utils.registry import DEFAULT_KEYS
+from ludwig.api_annotations import DeveloperAPI
+from ludwig.utils.torch_utils import LudwigModule
 
 
-class Encoder(Layer, ABC):
+@DeveloperAPI
+class Encoder(LudwigModule, ABC):
     @abstractmethod
-    def call(self, inputs, training=None, mask=None):
+    def forward(self, inputs, training=None, mask=None):
         raise NotImplementedError
 
-    @classmethod
-    @abstractmethod
-    def register(cls, name):
-        raise NotImplementedError
+    def get_embedding_layer(self) -> nn.Module:
+        """Returns layer that embeds inputs, used for computing explanations."""
+        return next(self.children())
 
-    @classmethod
-    def register_default(cls):
-        for key in DEFAULT_KEYS:
-            cls.register(name=key)
+    @property
+    def name(self):
+        return self.__class__.__name__
