@@ -29,7 +29,7 @@ from ludwig.contrib import add_contrib_callback_args
 from ludwig.globals import LUDWIG_VERSION
 from ludwig.utils.data_utils import load_config_from_str, load_yaml, save_json
 from ludwig.utils.defaults import default_random_seed
-from ludwig.utils.print_utils import logging_level_registry, print_ludwig, query_yes_no
+from ludwig.utils.print_utils import get_logging_level_registry, print_ludwig, query_yes_no
 
 logger = logging.getLogger(__name__)
 
@@ -162,7 +162,7 @@ def experiment_cli(
          for training.
      :param gpu_memory_limit: (float: default: `None`) maximum memory fraction
             [0, 1] allowed to allocate per GPU device.
-     :param allow_parallel_threads: (bool, default: `True`) allow TensorFlow
+     :param allow_parallel_threads: (bool, default: `True`) allow PyTorch
          to use multithreading parallelism to improve performance at
          the cost of determinism.
      :param callbacks: (list, default: `None`) a list of
@@ -491,7 +491,7 @@ def cli(sys_argv):
         "--disable_parallel_threads",
         action="store_false",
         dest="allow_parallel_threads",
-        help="disable TensorFlow from using multithreading for reproducibility",
+        help="disable PyTorch from using multithreading for reproducibility",
     )
     parser.add_argument(
         "-b",
@@ -515,7 +515,7 @@ def cli(sys_argv):
     for callback in args.callbacks:
         callback.on_cmdline("experiment", *sys_argv)
 
-    args.logging_level = logging_level_registry[args.logging_level]
+    args.logging_level = get_logging_level_registry()[args.logging_level]
     logging.getLogger("ludwig").setLevel(args.logging_level)
     global logger
     logger = logging.getLogger("ludwig.experiment")
