@@ -11,13 +11,12 @@ import pandas as pd
 import psutil
 import torch
 
-from ludwig.constants import COMBINED, LAST_HIDDEN, LOGITS
+from ludwig.constants import COMBINED, LAST_HIDDEN, LOGITS, MODEL_GBM
 from ludwig.data.dataset.base import Dataset
 from ludwig.data.utils import convert_to_dict
 from ludwig.distributed.base import DistributedStrategy, LocalStrategy
 from ludwig.globals import is_progressbar_disabled, PREDICTIONS_PARQUET_FILE_NAME, TEST_STATISTICS_FILE_NAME
 from ludwig.models.base import BaseModel
-from ludwig.models.gbm import GBM
 from ludwig.progress_bar import LudwigProgressBar
 from ludwig.utils.data_utils import save_csv, save_json
 from ludwig.utils.dataframe_utils import from_numpy_dataset
@@ -77,7 +76,7 @@ class Predictor(BasePredictor):
         self.report_tqdm_to_ray = report_tqdm_to_ray
 
         # TODO (jeffkinnison): revert to using the requested device for GBMs when device usage is fixed
-        self.device = get_torch_device() if not isinstance(model, GBM) else "cpu"
+        self.device = get_torch_device() if not model.type() == MODEL_GBM else "cpu"
         self.model = model.to(self.device)
 
     def batch_predict(self, dataset: Dataset, dataset_name: str = None, collect_logits: bool = False):
