@@ -1,8 +1,8 @@
 from abc import ABC, abstractmethod
-from typing import Any, Dict
 
 from ludwig.data.dataset.base import Dataset
 from ludwig.schema.trainer import BaseTrainerConfig
+from ludwig.types import ModelConfigDict
 from ludwig.utils.defaults import default_random_seed
 
 
@@ -21,7 +21,7 @@ class BaseTrainer(ABC):
     @abstractmethod
     def tune_batch_size(
         self,
-        config: Dict[str, Any],
+        config: ModelConfigDict,
         training_set: Dataset,
         random_seed: int = default_random_seed,
         max_trials: int = 10,
@@ -43,6 +43,13 @@ class BaseTrainer(ABC):
     def shutdown(self):
         pass
 
+    @property
+    def local_rank(self) -> int:
+        return 0
+
+    def barrier(self):
+        pass
+
     # Functions needed to treat Trainer as a context manager
     def __enter__(self):
         return self
