@@ -174,11 +174,16 @@ class Trainer(BaseTrainer):
         self.model = model
         self.model = self.model.to(self.device)
 
+        compiled_model = self.model
+        if config.compile:
+            compiled_model = torch.compile(self.model)
+            logger.info("Training with dynamo compiled model")
+
         # Some frameworks like DDP will wrap the model in a new interface that loses the methods from ECD. To
         # workaround this, we maintain a separate attribute for the wrapped model, which will be used for training
         # steps, while other operations happen on the original ECD model. Parameters are shared between the two models
         # so it is safe to train with the wrapped model and save the best model from the ECD model.
-        self.dist_model = self.distributed.wrap_model(self.model)
+        self.dist_model = self.distributed.wrap_model(compiled_model)
 
         # ================ Optimizer tuning ================
         optimizer_config = config.optimizer
