@@ -1,4 +1,3 @@
-import json
 import os
 from pathlib import Path
 
@@ -24,22 +23,7 @@ def change_test_dir(tmpdir, monkeypatch):
 def test_cache_dataset(use_cache_dir, use_split, use_df, tmpdir, change_test_dir):
     dataset_manager = PandasDatasetManager(backend=LocalTestBackend())
     cache_dir = os.path.join(tmpdir, "cache") if use_cache_dir else None
-
-    creds_fname = os.path.join(tmpdir, "credentials.json")
-    creds = {
-        "s3": {
-            "client_kwargs": {
-                "endpoint_url": "http://localhost:9000",
-                "aws_access_key_id": "test",
-                "aws_secret_access_key": "test",
-            }
-        }
-    }
-    with open(creds_fname, "w") as f:
-        json.dump(creds, f)
-
-    manager = CacheManager(dataset_manager, cache_dir=cache_dir, cache_credentials=creds_fname)
-    assert manager.credentials == creds
+    manager = CacheManager(dataset_manager, cache_dir=cache_dir)
 
     config = {
         "input_features": [sequence_feature(encoder={"reduce_output": "sum"})],
