@@ -36,14 +36,14 @@ IMAGE_DIR = tempfile.mkdtemp()
             [number_feature()],
         ),
         ([image_feature(IMAGE_DIR, encoder={"type": "stacked_cnn"})], [number_feature()]),
-        ([image_feature(IMAGE_DIR, encoder={"type": "resnet"})], [category_feature()]),
+        ([image_feature(IMAGE_DIR, encoder={"type": "stacked_cnn"})], [category_feature(output_feature=True)]),
         (
             [category_feature(encoder={"representation": "dense"})],
             [number_feature(decoder={"type": "regressor", "num_fc_layers": 5}, loss={"type": "mean_squared_error"})],
         ),
         ([date_feature()], [binary_feature()]),
         ([sequence_feature(encoder={"type": "parallel_cnn", "cell_type": "gru"})], [binary_feature()]),
-        ([set_feature()], [set_feature()]),
+        ([set_feature()], [set_feature(output_feature=True)]),
     ],
 )
 def test_regularizers(
@@ -65,12 +65,17 @@ def test_regularizers(
             "input_features": input_features,
             "output_features": output_features,
             "combiner": {"type": "concat", "output_size": 14},
-            TRAINER: {"epochs": 2, "regularization_type": regularization_type, "regularization_lambda": 0.1},
+            TRAINER: {
+                "epochs": 2,
+                "regularization_type": regularization_type,
+                "regularization_lambda": 0.1,
+                "batch_size": BATCH_SIZE,  # fix the batch size to ensure deterministic results
+            },
         }
 
         backend = LocalTestBackend()
         model = LudwigModel(config, backend=backend)
-        processed_data_df, _, _, _ = preprocess_for_training(config, data_df, backend=backend)
+        processed_data_df, _, _, _ = preprocess_for_training(model.config, data_df, backend=backend)
         with processed_data_df.initialize_batcher(batch_size=BATCH_SIZE) as batcher:
             batch = batcher.next_batch()
 
