@@ -78,7 +78,7 @@ def test_progress_tracker_empty():
             "input_size": 10,
         },
     )
-    output_features["category_feature"] = CategoryOutputFeature(category_feature, {})
+    output_features.set("category_feature", CategoryOutputFeature(category_feature, {}))
 
     progress_tracker = trainer_utils.get_new_progress_tracker(
         batch_size=5,
@@ -118,7 +118,7 @@ def test_progress_tracker():
             "input_size": 10,
         },
     )
-    output_features["category_feature"] = CategoryOutputFeature(category_feature, {})
+    output_features.set("category_feature", CategoryOutputFeature(category_feature, {}))
 
     progress_tracker = trainer_utils.get_new_progress_tracker(
         batch_size=5,
